==> scandit-titanium-datacapture-core-6.18.0-beta.1.tgz: modules/iphone/com.scandit.ti.datacapture.core/6.18.0-beta.1/platform/ScanditCaptureCore.xcframework/ios-arm64_x86_64-simulator/ScanditCaptureCore.framework/Headers/ScanditCaptureCore.h <==
/*
 * This file is part of the Scandit Data Capture SDK
 *
 * Copyright (C) 2017- Scandit AG. All rights reserved.
 */

#import <Foundation/Foundation.h>

FOUNDATION_EXPORT double ScanditCaptureCoreVersionNumber;

FOUNDATION_EXPORT const unsigned char ScanditCaptureCoreVersionString[];

#import <ScanditCaptureCore/SDCAimerViewfinder.h>
#import <ScanditCaptureCore/SDCAnchor.h>
#import <ScanditCaptureCore/SDCBase.h>
#import <ScanditCaptureCore/SDCBrush.h>
#import <ScanditCaptureCore/SDCCamera.h>
#import <ScanditCaptureCore/SDCCameraSettings.h>
#import <ScanditCaptureCore/SDCCameraSwitchControl.h>
#import <ScanditCaptureCore/SDCColorFillOverlay.h>
#import <ScanditCaptureCore/SDCColorUtilities.h>
#import <ScanditCaptureCore/SDCCombinedViewfinder.h>
#import <ScanditCaptureCore/SDCContextStatus.h>
#import <ScanditCaptureCore/SDCControl.h>
#import <ScanditCaptureCore/SDCDataCaptureComponent.h>
#import <ScanditCaptureCore/SDCDataCaptureComponentDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureContext.h>
#import <ScanditCaptureCore/SDCDataCaptureContextDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureContextDeserializerDelegate.h>
#import <ScanditCaptureCore/SDCDataCaptureContextDeserializerResult.h>
#import <ScanditCaptureCore/SDCDataCaptureContextSettings.h>
#import <ScanditCaptureCore/SDCDataCaptureMode.h>
#import <ScanditCaptureCore/SDCDataCaptureModeDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureOverlay.h>
#import <ScanditCaptureCore/SDCDataCaptureVersion.h>
#import <ScanditCaptureCore/SDCDataCaptureView.h>
#import <ScanditCaptureCore/SDCDataCaptureViewDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureViewDeserializerDelegate.h>
#import <ScanditCaptureCore/SDCDirection.h>
#import <ScanditCaptureCore/SDCEncodingRange.h>
#import <ScanditCaptureCore/SDCFeedback.h>
#import <ScanditCaptureCore/SDCFocusGesture.h>
#import <ScanditCaptureCore/SDCFocusGestureStrategy.h>
#import <ScanditCaptureCore/SDCFrameData.h>
#import <ScanditCaptureCore/SDCFrameSource.h>
#import <ScanditCaptureCore/SDCFrameSourceDeserializer.h>
#import <ScanditCaptureCore/SDCFrameSourceDeserializerDelegate.h>
#import <ScanditCaptureCore/SDCImageFrameSource.h>
#import <ScanditCaptureCore/SDCJSONValue.h>
#import <ScanditCaptureCore/SDCLaserlineViewfinder.h>
#import <ScanditCaptureCore/SDCLicenseInfo.h>
#import <ScanditCaptureCore/SDCLinearControlGroup.h>
#import <ScanditCaptureCore/SDCLocationSelection.h>
#import <ScanditCaptureCore/SDCLocationSelectionDeserializer.h>
#import <ScanditCaptureCore/SDCMacroModeControl.h>
#import <ScanditCaptureCore/SDCMeasureUnit.h>
#import <ScanditCaptureCore/SDCQuadrilateral.h>
#import <ScanditCaptureCore/SDCRectangularViewfinder.h>
#import <ScanditCaptureCore/SDCRectangularViewfinderAnimation.h>
#import <ScanditCaptureCore/SDCSequenceFrameSource.h>
#import <ScanditCaptureCore/SDCSizeWithUnitAndAspect.h>
#import <ScanditCaptureCore/SDCSound.h>
#import <ScanditCaptureCore/SDCSpotlightViewfinder.h>
#import <ScanditCaptureCore/SDCTorchSwitchControl.h>
#import <ScanditCaptureCore/SDCVibration.h>
#import <ScanditCaptureCore/SDCViewfinder.h>
#import <ScanditCaptureCore/SDCViewfinderDeserializer.h>
#import <ScanditCaptureCore/SDCWaveFormVibration.h>
#import <ScanditCaptureCore/SDCZoomGesture.h>
#import <ScanditCaptureCore/SDCZoomSwitchControl.h>

==> scandit-titanium-datacapture-core-7.0.0-beta.1.tgz: modules/iphone/com.scandit.ti.datacapture.core/7.0.0-beta.1/platform/ScanditCaptureCore.xcframework/ios-arm64_x86_64-simulator/ScanditCaptureCore.framework/Headers/ScanditCaptureCore.h <==
/*
 * This file is part of the Scandit Data Capture SDK
 *
 * Copyright (C) 2017- Scandit AG. All rights reserved.
 */

#import <Foundation/Foundation.h>

FOUNDATION_EXPORT double ScanditCaptureCoreVersionNumber;

FOUNDATION_EXPORT const unsigned char ScanditCaptureCoreVersionString[];

// clang-format off
#import <ScanditCaptureCore/SDCAimerViewfinder.h>
#import <ScanditCaptureCore/SDCAnchor.h>
#import <ScanditCaptureCore/SDCBase.h>
#import <ScanditCaptureCore/SDCBatterySavingMode.h>
#import <ScanditCaptureCore/SDCBrush.h>
#import <ScanditCaptureCore/SDCCamera.h>
#import <ScanditCaptureCore/SDCCameraSettings.h>
#import <ScanditCaptureCore/SDCCameraSwitchControl.h>
#import <ScanditCaptureCore/SDCColorFillOverlay.h>
#import <ScanditCaptureCore/SDCColorUtilities.h>
#import <ScanditCaptureCore/SDCContextStatus.h>
#import <ScanditCaptureCore/SDCControl.h>
#import <ScanditCaptureCore/SDCDataCaptureComponent.h>
#import <ScanditCaptureCore/SDCDataCaptureComponentDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureContext.h>
#import <ScanditCaptureCore/SDCDataCaptureContextDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureContextDeserializerDelegate.h>
#import <ScanditCaptureCore/SDCDataCaptureContextDeserializerResult.h>
#import <ScanditCaptureCore/SDCDataCaptureContextSettings.h>
#import <ScanditCaptureCore/SDCDataCaptureMode.h>
#import <ScanditCaptureCore/SDCDataCaptureModeDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureOverlay.h>
#import <ScanditCaptureCore/SDCDataCaptureVersion.h>
#import <ScanditCaptureCore/SDCDataCaptureView.h>
#import <ScanditCaptureCore/SDCDataCaptureViewDeserializer.h>
#import <ScanditCaptureCore/SDCDataCaptureViewDeserializerDelegate.h>
#import <ScanditCaptureCore/SDCDirection.h>
#import <ScanditCaptureCore/SDCEncodingRange.h>
#import <ScanditCaptureCore/SDCFeedback.h>
#import <ScanditCaptureCore/SDCFocusGesture.h>
#import <ScanditCaptureCore/SDCFocusGestureStrategy.h>
#import <ScanditCaptureCore/SDCFrameData.h>
#import <ScanditCaptureCore/SDCFrameSource.h>
#import <ScanditCaptureCore/SDCFrameSourceDeserializer.h>
#import <ScanditCaptureCore/SDCFrameSourceDeserializerDelegate.h>
#import <ScanditCaptureCore/SDCImageFrameSource.h>
#import <ScanditCaptureCore/SDCJSONValue.h>
#import <ScanditCaptureCore/SDCLicenseInfo.h>
#import <ScanditCaptureCore/SDCLinearControlGroup.h>
#import <ScanditCaptureCore/SDCLocationSelection.h>
#import <ScanditCaptureCore/SDCLocationSelectionDeserializer.h>
#import <ScanditCaptureCore/SDCMacroModeControl.h>
#import <ScanditCaptureCore/SDCMeasureUnit.h>
#import <ScanditCaptureCore/SDCOpenSourceSoftwareLicenseInfo.h>
#import <ScanditCaptureCore/SDCQuadrilateral.h>
#import <ScanditCaptureCore/SDCRectangularViewfinder.h>
#import <ScanditCaptureCore/SDCRectangularViewfinderAnimation.h>
#import <ScanditCaptureCore/SDCScanIntention.h>
#import <ScanditCaptureCore/SDCSequenceFrameSource.h>
#import <ScanditCaptureCore/SDCSizeWithUnitAndAspect.h>
#import <ScanditCaptureCore/SDCSound.h>
#import <ScanditCaptureCore/SDCTorchSwitchControl.h>
#import <ScanditCaptureCore/SDCVibration.h>
#import <ScanditCaptureCore/SDCViewfinder.h>
#import <ScanditCaptureCore/SDCViewfinderDeserializer.h>
#import <ScanditCaptureCore/SDCWaveFormVibration.h>
#import <ScanditCaptureCore/SDCZoomGesture.h>
#import <ScanditCaptureCore/SDCZoomSwitchControl.h>

// clang-format on
